package org.iphsoft.simon1.util;

import android.content.Context;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Point;
import android.graphics.drawable.BitmapDrawable;
import android.view.View;

import java.util.HashMap;

public class BitmapUtils {

	/**
	 * Handy function for setting a scaled down background to a view (in order
	 * to avoid OutOfMeFmory). It keeps decoded backgrounds in a HashMap to
	 * prevent later decoding operations.
	 * 
	 * @param view
	 * @param resource
	 */
	public static void setScaledBackground(Context context, View view, int resource)
	{
		Bitmap bg;

		// Check if the bitmap is in our cache
		if (sBackgroundBitmapCache.containsKey(resource))
		{
			MyLog.d("BitmapUtils: setScaledBackground: cached");
			bg = sBackgroundBitmapCache.get(resource);
		} else
		{
			MyLog.d("BitmapUtils: setScaledBackground: not cached");
			// If not, decode it and store in the cache
			Point displaySize = DisplayUtils.getWindowSize(context);
			bg = BitmapUtils.decodeSampledBitmapFromResource(context.getResources(), resource,
					displaySize.x, displaySize.y);
			sBackgroundBitmapCache.put(resource, bg);
		}
		
		view.setBackgroundDrawable(new BitmapDrawable(bg));
	}

	/**
	 * Code from Google - get a scaled down bitmap from a resource to save
	 * memory
	 */
	private static Bitmap decodeSampledBitmapFromResource(Resources res, int resId, int reqWidth,
			int reqHeight)
	{
		// First decode with inJustDecodeBounds=true to check dimensions
		final BitmapFactory.Options options = new BitmapFactory.Options();
		options.inJustDecodeBounds = true;
		BitmapFactory.decodeResource(res, resId, options);

		// Calculate inSampleSize
		options.inSampleSize = calculateInSampleSize(options, reqWidth, reqHeight);

		// Decode bitmap with inSampleSize set
		options.inJustDecodeBounds = false;
		try
		{
			return BitmapFactory.decodeResource(res, resId, options);
		} catch (OutOfMemoryError e)
		{
			// HACK: from Google Play crash report: if OutOfMemory exception,
			// increase sample size and decode again
			MyLog.e("BitmapUtils: decodeSampledBitmapFromResource: OutOfMemoryError, increasing sample size");
			options.inSampleSize *= 2;
			return BitmapFactory.decodeResource(res, resId, options);
		}
	}

	/**
	 * Code from Google
	 */
	private static int calculateInSampleSize(BitmapFactory.Options options, int reqWidth,
			int reqHeight)
	{
		// Raw height and width of image
		final int height = options.outHeight;
		final int width = options.outWidth;
		int inSampleSize = 1;

		if (height > reqHeight || width > reqWidth)
		{

			final int halfHeight = height / 2;
			final int halfWidth = width / 2;

			// Calculate the largest inSampleSize value that is a power of 2 and
			// keeps both
			// height and width larger than the requested height and width.
			while ((halfHeight / inSampleSize) > reqHeight && (halfWidth / inSampleSize) > reqWidth)
			{
				inSampleSize *= 2;
			}
		}

		return inSampleSize;
	}

	private static HashMap<Integer, Bitmap> sBackgroundBitmapCache = new HashMap<Integer, Bitmap>();
}
